==> openshift-model-operatorhub-4.13.3-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/manifests/PackageManifestBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.manifests;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PackageManifestBuilder extends PackageManifestFluentImpl<PackageManifestBuilder> implements VisitableBuilder<PackageManifest,PackageManifestBuilder> {

    PackageManifestFluent<?> fluent;
    Boolean validationEnabled;

    public PackageManifestBuilder() { 
        this(true);
    }


    public PackageManifestBuilder(Boolean validationEnabled) { 
        this(new PackageManifest(), validationEnabled);
    }


    public PackageManifestBuilder(PackageManifestFluent<?> fluent) { 
        this(fluent, true);
    }


    public PackageManifestBuilder(PackageManifestFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new PackageManifest(), validationEnabled);
    }


    public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance) { 
        this(fluent, instance, true);
    }


    public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withChannels(instance.getChannels()); 
        fluent.withDefaultChannel(instance.getDefaultChannel()); 
        fluent.withPackageName(instance.getPackageName()); 
        this.validationEnabled = validationEnabled; 
    }


    public PackageManifestBuilder(PackageManifest instance) { 
        this(instance,true);
    }


    public PackageManifestBuilder(PackageManifest instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withChannels(instance.getChannels()); 
        this.withDefaultChannel(instance.getDefaultChannel()); 
        this.withPackageName(instance.getPackageName()); 
        this.validationEnabled = validationEnabled; 
    }


    public PackageManifest build() {
        PackageManifest buildable = new PackageManifest(fluent.getChannels(),fluent.getDefaultChannel(),fluent.getPackageName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PackageManifestBuilder that = (PackageManifestBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operatorhub-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/manifests/PackageManifestBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.manifests;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PackageManifestBuilder extends PackageManifestFluentImpl<PackageManifestBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<PackageManifest,PackageManifestBuilder> {

    PackageManifestFluent<?> fluent;
    Boolean validationEnabled;

    public PackageManifestBuilder() {
        this(true);
    }

    public PackageManifestBuilder(Boolean validationEnabled) {
        this(new PackageManifest(), validationEnabled);
    }

    public PackageManifestBuilder(PackageManifestFluent<?> fluent) {
        this(fluent, true);
    }

    public PackageManifestBuilder(PackageManifestFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PackageManifest(), validationEnabled);
    }

    public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance) {
        this(fluent, instance, true);
    }

    public PackageManifestBuilder(PackageManifestFluent<?> fluent,PackageManifest instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withChannels(instance.getChannels()); 
        fluent.withDefaultChannel(instance.getDefaultChannel()); 
        fluent.withPackageName(instance.getPackageName()); 
        this.validationEnabled = validationEnabled; 
    }

    public PackageManifestBuilder(PackageManifest instance) {
        this(instance,true);
    }

    public PackageManifestBuilder(PackageManifest instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withChannels(instance.getChannels()); 
        this.withDefaultChannel(instance.getDefaultChannel()); 
        this.withPackageName(instance.getPackageName()); 
        this.validationEnabled = validationEnabled; 
    }

    public PackageManifest build() {
        PackageManifest buildable = new PackageManifest(fluent.getChannels(),fluent.getDefaultChannel(),fluent.getPackageName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PackageManifestBuilder that = (PackageManifestBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
